
## 210928_GFP-V_entry_Mib1_disociation

### Set the environment -------------------------

library("tidyr")
library("tidyverse")
library("dplyr")

library("stringr")
library("ggplot2")
library("reshape2")
library("Hmisc")
library("RColorBrewer")

library("lattice")
library("gplots")

### Prepare every function that you need --------------------

as.numeric.factor <- function(x){
  as.numeric(levels(x))[x]
}

### Input your sample ----------------------------------

setwd("N://Alfonso_Gomez//1 - Experimental Procedures//210928_GFP-V_entry_Mib1_disociation//CellProfAnalys")

Masked_virus <- read.csv2("210928_entry_GFP-V_Mib1_Maskedvirus.csv", header = T, sep = ",")
Expanded_virus <- read.csv2("210928_entry_GFP-V_Mib1_Big_Vir.csv", header = T, sep = ",")

# Transform values to floats
Masked_virus$Intensity_MeanIntensity_GFP <- as.numeric.factor(Masked_virus$Intensity_MeanIntensity_GFP)
Expanded_virus$Intensity_MeanIntensity_GFP <- as.numeric.factor(Expanded_virus$Intensity_MeanIntensity_GFP)

# Take only the useful data
Compact_Mask <- Masked_virus[c("Metadata_sample","Metadata_Site","Intensity_MeanIntensity_GFP", "Number_Object_Number","Parent_Cell", "Parent_Nuclus")]
Compact_Expansion <- Expanded_virus[c("Metadata_sample","Metadata_Site","Intensity_MeanIntensity_GFP", "Number_Object_Number")]

# Rename the columns
colnames(Compact_Mask)
names(Compact_Mask)[names(Compact_Mask) == "Intensity_MeanIntensity_GFP"] <- "Particle_GFP_Intensity"
names(Compact_Expansion)[names(Compact_Expansion) == "Intensity_MeanIntensity_GFP"] <- "Background_GFP_Intensity"

# Merge both data.frames
Merged_data <- cbind(Compact_Mask, "Background_GFP_Intensity" = Compact_Expansion[, "Background_GFP_Intensity"])

# Transform values to floats
Merged_data$Particle_GFP_Intensity <- as.numeric.factor(Merged_data$Particle_GFP_Intensity)
Merged_data$Background_GFP_Intensity <- as.numeric.factor(Merged_data$Background_GFP_Intensity)

Improved_data <- cbind(Merged_data, "GFP_ratio"= Merged_data[,"Particle_GFP_Intensity"]/Merged_data[,"Background_GFP_Intensity"])

ggplot(data = Improved_data,aes(x = Metadata_sample, y = GFP_ratio))+
  geom_dotplot(binaxis='y', stackdir='center',
               stackratio=0.01, dotsize=0.3, alpha=0.5, position = position_jitter(width = 0.2)) +
  geom_boxplot(color = "black", outlier.colour = NA) +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  ylab("GFP ratio to background") +
  ylim(0,5.0) +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))

Following_patterns <- unique(Masked_virus$Metadata_sample, incomparables = FALSE)
print(Following_patterns)

### Measure your sample --------------------------------

# You should input into the function 
# The data frame containing your data
# The number of splits "_" depeding on the sample name for teh regular expression
# The theshold that you want to set into the hexon

New_genome_counting_2 <- function(exp,strng,thres){
  output2 <- matrix(nrow = 0, ncol = 10)
  exp_size <- unique(exp$Metadata_sample, incomparables = FALSE)
  for (f in seq_along(exp_size)){
    samp <- as.character(exp_size[f])
    Split <- str_split_fixed(samp,"_",n = strng)
    Cell_type <- Split[,5]
    Treat <- Split[,4]
    sec_spl <- str_split_fixed(samp,"_",n = strng-2)
    good_samp <- sec_spl[,4]
    Time <- as.numeric(Split[,6])
    sample_matrix <- exp[exp$Metadata_sample== samp,]
    sites <- unique(sample_matrix$Metadata_Site, incomparables = FALSE)
    for (sit in seq_along(sites)){
      place <- as.character(sites[sit])
      ce <- subset(sample_matrix, (sample_matrix$Metadata_Site == place))
      ncel <- max(ce$Parent_Cell, na.rm = T)
      if (ncel==-Inf){
        output2 <- output2
      } else {
        for (c in 1:ncel){
          VP <- length(ce[ce[,"Parent_Cell"] == c,][,1])
          Pos_VP <- dim(ce[(ce$Intensity_MeanIntensity_GFP > thres) & (ce$Parent_Cell == c),])[1]
          Nucleus <- length(ce[ce[,"Parent_Nuclus"] == c,][,1])
          if (VP == 0){
            Percent_Pos <- 0
            Percent_Nuc <- 0
          } else {
            Percent_Pos <- (Pos_VP/VP)*100
            Percent_Nuc <- (Nucleus/VP)*100
          }
          output2 <- rbind(output2,c(good_samp, Cell_type, Treat, Time, c, VP, Nucleus,Percent_Nuc, Pos_VP,Percent_Pos))
        }
      }
    }
  }
  colnames(output2) <- c("Sample","Cell_type","Treatment","Time","Cell", "VP", "Nuclear_VP",
                         "Percent_Nuc","Pos_VP","Percent_Pos")
  output2 <- as.data.frame(output2)
  output2$Time <- as.numeric.factor(output2$Time)
  output2$Cell <- as.numeric.factor(output2$Cell)
  output2$VP <- as.numeric.factor(output2$VP)
  output2$Nuclear_VP <- as.numeric.factor(output2$Nuclear_VP)
  output2$Percent_Nuc <- as.numeric.factor(output2$Percent_Nuc)
  output2$Pos_VP <- as.numeric.factor(output2$Pos_VP)
  output2$Percent_Pos <- as.numeric.factor(output2$Percent_Pos)
  return(output2)
}

GFP_Count_2 <- New_genome_counting_2(Masked_virus, 6, 0.08)

## Do the plots ------------------------------------------------------------

ggplot(data = GFP_Count_2,aes(x = Sample, y = Percent_Pos))+
  geom_dotplot(binaxis='y', stackdir='center',
               stackratio=0.01, dotsize=0.3, alpha=0.5, position = position_jitter(width = 0.2)) +
  geom_boxplot(color = "black", outlier.colour = NA) +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  ylab("EdC intensity in VP") +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))

write.csv2(GFP_Count_2, file = "210928_GFP-V_disociation_cell_percentages.csv")


##
## We want to try to combine the virus and the expanded virus -------------------
##


GFP_colocalization_counting_2 <- function(exp,strng,thres, Rat){
  output2 <- matrix(nrow = 0, ncol = 12)
  exp_size <- unique(exp$Metadata_sample, incomparables = FALSE)
  for (f in seq_along(exp_size)){
    samp <- as.character(exp_size[f])
    Split <- str_split_fixed(samp,"_",n = strng)
    Cell_type <- Split[,5]
    Treat <- Split[,4]
    sec_spl <- str_split_fixed(samp,"_",n = strng-2)
    good_samp <- sec_spl[,4]
    Time <- as.numeric(Split[,6])
    sample_matrix <- exp[exp$Metadata_sample== samp,]
    sites <- unique(sample_matrix$Metadata_Site, incomparables = FALSE)
    for (sit in seq_along(sites)){
      place <- as.character(sites[sit])
      ce <- subset(sample_matrix, (sample_matrix$Metadata_Site == place))
      ncel <- max(ce$Parent_Cell, na.rm = T)
      if (ncel==-Inf){
        output2 <- output2
      } else {
        for (c in 1:ncel){
          VP <- length(ce[ce[,"Parent_Cell"] == c,][,1])
          Pos_VP <- dim(ce[(ce$Particle_GFP_Intensity > thres) & (ce$Parent_Cell == c),])[1]
          Pos_ratio <- dim(ce[(ce$GFP_ratio > Rat) & (ce$Parent_Cell == c),])[1]
          Nucleus <- length(ce[ce[,"Parent_Nuclus"] == c,][,1])
          if (VP == 0){
            Percent_Pos <- 0
            Percent_ratio <- 0
            Percent_Nuc <- 0
          } else {
            Percent_Pos <- (Pos_VP/VP)*100
            Percent_ratio <- (Pos_ratio/VP)*100
            Percent_Nuc <- (Nucleus/VP)*100
          }
          output2 <- rbind(output2,c(good_samp, Cell_type, Treat, Time, c, VP, Nucleus,Percent_Nuc, Pos_VP,Percent_Pos, Pos_ratio, Percent_ratio))
        }
      }
    }
  }
  colnames(output2) <- c("Sample","Cell_type","Treatment","Time","Cell", "VP", "Nuclear_VP",
                         "Percent_Nuc","Pos_VP","Percent_Pos", "Pos_ratio","Percent_ratio")
  output2 <- as.data.frame(output2)
  output2$Time <- as.numeric.factor(output2$Time)
  output2$Cell <- as.numeric.factor(output2$Cell)
  output2$VP <- as.numeric.factor(output2$VP)
  output2$Nuclear_VP <- as.numeric.factor(output2$Nuclear_VP)
  output2$Percent_Nuc <- as.numeric.factor(output2$Percent_Nuc)
  output2$Pos_VP <- as.numeric.factor(output2$Pos_VP)
  output2$Percent_Pos <- as.numeric.factor(output2$Percent_Pos)
  output2$Pos_ratio <- as.numeric.factor(output2$Pos_ratio)
  output2$Percent_ratio <- as.numeric.factor(output2$Percent_ratio)
  return(output2)
}

Ratio_calc_15 <- GFP_colocalization_counting_2(Improved_data, 6, 0.08, 1.5)
Ratio_calc_20 <- GFP_colocalization_counting_2(Improved_data, 6, 0.08, 2)

ggplot(data = Ratio_calc,aes(x = Sample, y = Percent_Pos))+
  geom_dotplot(binaxis='y', stackdir='center',
               stackratio=0.01, dotsize=0.3, alpha=0.5, position = position_jitter(width = 0.2)) +
  geom_boxplot(color = "black", outlier.colour = NA) +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  ylab("EdC intensity in VP") +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))

ggplot(data = Ratio_calc,aes(x = Sample, y = Percent_ratio))+
  geom_dotplot(binaxis='y', stackdir='center',
               stackratio=0.01, dotsize=0.3, alpha=0.5, position = position_jitter(width = 0.2)) +
  geom_boxplot(color = "black", outlier.colour = NA) +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  ylab("EdC intensity in VP") +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))


write.csv2(Ratio_calc_15, file = "210929_GFP-V_ratio_15_disociation_percentages.csv")
write.csv2(Ratio_calc_20, file = "210929_GFP-V_ratio_20_disociation_percentages.csv")


